<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 12/14/2010	ELL
// Revised: 2/8/2012	ELL
// Added table prefix handling.
// 
// 
	
	include ("check_session.php");
	
	$menu = $_REQUEST['menu'];
	if (!isset($menu))
		$menu = $_SESSION['last_menu_edited'];
	else
		$_SESSION['last_menu_edited'] = $menu;
	
	$suffix = substr($menu, 4);
	$menu_source  = "menu" . $suffix . "_items";
	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_source . " ORDER BY sort_order";
	$result = $bwb_dbh->query($query);
	
	if ($result->rowCount() < 1)
	{
		echo "-no data-";
		exit;
	}

	$row_delim = "";
	while ($row = $result->fetch(PDO::FETCH_ASSOC))
	{
//		$row['item_text'] = str_replace('AMPERSAND', '&', $row['item_text']);
//		$row['item_text'] = str_replace('SEMICOLON', ';', $row['item_text']);
		$row['item_text'] = stripslashes($row['item_text']);
		$table .= $row_delim . json_encode($row);
		$row_delim = "@@@@@";
	}
	
	print $table;

?>